# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: txt文件断言
# @Time   : 2025-07-04
# @Author : 毛鹏

from mangotools.decorator import sync_method_callback
from mangotools.models import MethodModel

class TxtAssertion:
    """txt文件"""

    @staticmethod
    @sync_method_callback('文件断言', 'txt断言', 0, [
        MethodModel(f='actual', p='实际内容或文件路径', d=True),
        MethodModel(f='expect', p='期望内容', d=True),
    ])
    def assert_txt_equal(actual: str, expect: str):
        """内容完全相等"""
        if actual.endswith('.txt'):
            with open(actual, encoding='utf-8') as f:
                actual_content = f.read()
        else:
            actual_content = actual
        print(actual_content, expect)
        assert actual_content == expect, f'实际内容={actual_content}, 期望内容={expect}'

    @staticmethod
    @sync_method_callback('文件断言', 'txt断言', 1, [
        MethodModel(f='actual', p='实际内容或文件路径', d=True),
        MethodModel(f='expect', p='期望包含内容', d=True),
    ])
    def assert_txt_contains(actual: str, expect: str):
        """内容包含指定字符串"""
        if actual.endswith('.txt'):
            with open(actual, encoding='utf-8') as f:
                actual_content = f.read()
        else:
            actual_content = actual
        assert expect in actual_content, f'实际内容={actual_content}, 期望包含={expect}'

    @staticmethod
    @sync_method_callback('文件断言', 'txt断言', 2, [
        MethodModel(f='actual', p='实际内容或文件路径', d=True),
        MethodModel(f='expect', p='期望长度', d=True),
    ])
    def assert_txt_length_equal(actual: str, expect: int):
        """内容长度等于期望值"""
        if actual.endswith('.txt'):
            with open(actual, encoding='utf-8') as f:
                actual_content = f.read()
        else:
            actual_content = actual
        assert len(actual_content) == int(expect), f'实际长度={len(actual_content)}, 期望长度={expect}'

    @staticmethod
    @sync_method_callback('文件断言', 'txt断言', 3, [
        MethodModel(f='actual', p='实际内容或文件路径', d=True),
        MethodModel(f='expect', p='期望开头内容', d=True),
    ])
    def assert_txt_startswith(actual: str, expect: str):
        """内容以指定字符串开头"""
        if actual.endswith('.txt'):
            with open(actual, encoding='utf-8') as f:
                actual_content = f.read()
        else:
            actual_content = actual
        assert actual_content.startswith(expect), f'实际内容={actual_content}, 期望开头={expect}'

    @staticmethod
    @sync_method_callback('文件断言', 'txt断言', 4, [
        MethodModel(f='actual', p='实际内容或文件路径', d=True),
        MethodModel(f='expect', p='期望结尾内容', d=True),
    ])
    def assert_txt_endswith(actual: str, expect: str):
        """内容以指定字符串结尾"""
        if actual.endswith('.txt'):
            with open(actual, encoding='utf-8') as f:
                actual_content = f.read()
        else:
            actual_content = actual
        assert actual_content.endswith(expect), f'实际内容={actual_content}, 期望结尾={expect}'



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2023-11-20 9:47
# @Author : 毛鹏
from deepdiff import DeepDiff

from mangotools.database import MysqlConnect
from mangotools.decorator import sync_method_callback
from mangotools.models import MethodModel


class MysqlAssertion:
    """mysql"""

    def __init__(self, mysql_connect: MysqlConnect | None):
        self.mysql_connect: MysqlConnect = mysql_connect

    @sync_method_callback('sql断言', 'mysql', 1, [
        MethodModel(f='actual', p='请输入sql语句', d=True),
        MethodModel(f='expect', p='期望条数', d=True),
    ])
    async def assert_sql_count(self, actual: str, expect: int):
        """SQL查询结果条数"""
        result = self.mysql_connect.condition_execute(actual)
        assert len(result) == int(expect), f'实际条数={len(result)}, 预期条数={expect}'

    @sync_method_callback('sql断言', 'mysql', 2, [
        MethodModel(f='actual', p='请输入sql语句', d=True),
        MethodModel(f='expect', p='请输入期望的dict', d=True),
    ])
    async def assert_sql_first_row(self, actual: str, expect: dict):
        """数据相等"""
        result = self.mysql_connect.condition_execute(actual)
        assert result, f'实际={result}, 预期={expect}'
        first_row = result[0]
        diff = DeepDiff(first_row, expect, ignore_order=True)
        assert not diff, f'实际={actual}, 预期={expect}'

    @sync_method_callback('sql断言', 'mysql', 3, [
        MethodModel(f='actual', p='请输入sql语句', d=True),
        MethodModel(f='expect', p='期望字段及值', d=True,
                    v={'key': '请输入对应查询语句中的key', 'value': '请输入期望结果'}),
    ])
    async def assert_sql_value_in_first_row(self, actual: str, expect: dict):
        """值相等"""
        result = self.mysql_connect.condition_execute(actual)
        assert result, f'实际={result}, 预期={expect}'
        first_row = result[0]
        for k, v in expect.items():
            assert first_row.get(k) == v, f'字段{k}实际值={first_row.get(k)}, 预期值={v}'


if __name__ == '__main__':
    _sql = "SELECT id,`name`,`status` FROM `project`;"
    _expect = [{'id': 2, 'name': '1CDXP', 'status': 1}, {'id': 5, 'name': 'AIGC', 'status': 1},
               {'id': 10, 'name': 'DESK', 'status': 1}, {'id': 11, 'name': 'AIGC-SaaS', 'status': 1}]



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2025-06-26 10:43
# @Author : 毛鹏
import unittest

from cachetools import LRUCache

from mangotools.data_processor import CacheTool


class TestCacheTool(unittest.TestCase):
    def setUp(self):
        """在每个测试方法前初始化"""
        self.cache = CacheTool()

    def test_basic_operations(self):
        """测试基本缓存操作"""
        # 测试设置和获取缓存
        self.cache.set_cache('name', 'Alice')
        self.assertEqual(self.cache.get_cache('name'), 'Alice')

        # 测试缓存是否存在
        self.assertTrue(self.cache.has_cache('name'))
        self.assertFalse(self.cache.has_cache('nonexistent'))

        # 测试删除缓存
        self.cache.delete_cache('name')
        self.assertIsNone(self.cache.get_cache('name'))

    def test_clear_cache(self):
        """测试清空缓存"""
        self.cache.set_cache('key1', 'value1')
        self.cache.set_cache('key2', 'value2')
        self.cache.clear_cache()
        self.assertEqual(len(self.cache.get_all()), 0)

    def test_get_all(self):
        """测试获取所有缓存"""
        self.cache.set_cache('a', 1)
        self.cache.set_cache('b', 2)
        all_cache = self.cache.get_all()
        self.assertEqual(all_cache, {'a': 1, 'b': 2})

    def test_set_sql_cache(self):
        """测试SQL式缓存设置"""
        keys = 'id,name ,age'
        values = {'id': 1, 'name': 'Bob', 'age': 30}
        self.cache.set_sql_cache(keys, values)

        self.assertEqual(self.cache.get_cache('id'), 1)
        self.assertEqual(self.cache.get_cache('name'), 'Bob')
        self.assertEqual(self.cache.get_cache('age'), 30)

    def test_set_list_cache(self):
        """测试列表缓存设置"""
        keys = ['k1', 'k2', 'k3']
        values = ['v1', 'v2', 'v3']
        self.cache.set_list_cache(keys, values)

        self.assertEqual(self.cache.get_cache('k1'), 'v1')
        self.assertEqual(self.cache.get_cache('k2'), 'v2')
        self.assertEqual(self.cache.get_cache('k3'), 'v3')

    def test_set_dict_cache(self):
        """测试字典缓存设置"""
        data = {
            'color': 'red',
            'size': 'large',
            'price': 99.9
        }
        self.cache.set_dict_cache(data)

        self.assertEqual(self.cache.get_cache('color'), 'red')
        self.assertEqual(self.cache.get_cache('size'), 'large')
        self.assertEqual(self.cache.get_cache('price'), 99.9)

    def test_lru_eviction(self):
        """测试LRU淘汰机制"""
        # 创建最大容量为3的缓存
        small_cache = CacheTool()
        small_cache._cache = LRUCache(maxsize=3)

        small_cache.set_cache('1', 'one')
        small_cache.set_cache('2', 'two')
        small_cache.set_cache('3', 'three')

        # 访问'1'使其成为最近使用的
        small_cache.get_cache('1')

        # 添加第四个元素，应该淘汰'2'（因为'1'被访问过，'3'是最久未使用的）
        small_cache.set_cache('4', 'four')

        self.assertEqual(len(small_cache.get_all()), 3)
        self.assertIsNone(small_cache.get_cache('2'))
        self.assertEqual(small_cache.get_cache('1'), 'one')
        self.assertEqual(small_cache.get_cache('3'), 'three')
        self.assertEqual(small_cache.get_cache('4'), 'four')


if __name__ == '__main__':
    unittest.main()



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2025-07-04 14:09
# @Author : 毛鹏
from ...data_processor import DataProcessor
from ...decorator import sync_method_callback
from ...exceptions import MangoToolsError
from ...exceptions.error_msg import ERROR_MSG_0061
from ...models import MethodModel


class CustomAssertion:
    """函数断言"""

    def __init__(self, test_data: DataProcessor):
        self.test_data = test_data

    @staticmethod
    @sync_method_callback('函数断言', '函数断言', 7, [
        MethodModel(f='func_str', p='请输入一个函数，在函数里面自己断言', d=True),
        MethodModel(f='func_name', p='请输入这个函数的名称', d=True), ])
    def ass_func(func_str, func_name='func'):
        """输入断言代码"""
        try:
            global_namespace = {}
            exec(func_str, global_namespace)
            return global_namespace[func_name]
        except (KeyError, SyntaxError, TypeError):
            import traceback
            traceback.print_exc()
            raise MangoToolsError(*ERROR_MSG_0061)



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2023-08-30 14:20
# @Author : 毛鹏
import json
import sqlite3
from typing import Any

from ..database import SQLiteConnect
from ..enums import CacheValueTypeEnum


class SqlCache:
    """文件缓存"""
    create_table_query1 = '''
    CREATE TABLE "cache_mango_2023" (
      "id" INTEGER PRIMARY KEY AUTOINCREMENT,
      "key" TEXT NOT NULL,
      "value" TEXT,
      "case_id" TEXT,
      "type" INTEGER,
      "internal" INTEGER
    );
    '''

    def __init__(self, cache_path):
        self.cache_path = cache_path
        self.conn = SQLiteConnect(self.cache_path)
        for i in [self.create_table_query1]:
            try:
                self.conn.execute(i)
            except sqlite3.OperationalError:
                pass
        self.sql_statement_2 = f'SELECT * FROM cache_mango_2023;'
        self.sql_statement_4 = f'INSERT INTO "cache_mango_2023" ("key", "value", "type") VALUES (?, ?, ?);'
        self.sql_statement_5 = f'SELECT * FROM cache_mango_2023 WHERE `key` = ?;'
        self.sql_statement_6 = f'DELETE FROM cache_mango_2023 WHERE `key` = ?;'
        self.sql_statement_7 = f'SELECT COUNT(*) FROM cache_mango_2023 WHERE `key` = ?;'
        self.sql_statement_8 = f'DELETE FROM cache_mango_2023;'

    def get_sql_cache(self, key: str) -> [str, list, dict, int, float, bool, tuple, None]:
        """
        获取缓存中指定键的值
        :param key: 缓存键
        :return:
        """
        res = self.conn.execute(self.sql_statement_5, (key,))
        if res:
            res = res[0]
        else:
            return None

        value = res.get('value')
        value_type = res.get('type')

        if value_type == CacheValueTypeEnum.STR.value:
            return value if value != '' else None
        elif value_type == CacheValueTypeEnum.INT.value:
            return int(value)
        elif value_type == CacheValueTypeEnum.FLOAT.value:
            return float(value)
        elif value_type == CacheValueTypeEnum.BOOL.value:
            return value.lower() == 'true'
        elif value_type == CacheValueTypeEnum.NONE.value:
            return None
        elif value_type == CacheValueTypeEnum.LIST.value:
            return json.loads(value)
        elif value_type == CacheValueTypeEnum.DICT.value:
            return json.loads(value)
        elif value_type == CacheValueTypeEnum.TUPLE.value:
            return tuple(json.loads(value))
        elif value_type == CacheValueTypeEnum.JSON.value:
            return json.loads(value)
        return value

    def set_sql_cache(self, key: str, value: Any, value_type: CacheValueTypeEnum = CacheValueTypeEnum.STR) -> None:
        """
        设置缓存键的值
        :param key: 缓存键
        :param value: 缓存值
        :param value_type: 值类型
        :return: None
        """
        if value_type == CacheValueTypeEnum.STR:
            str_value = str(value)
        elif value_type == CacheValueTypeEnum.INT:
            str_value = str(int(value))
        elif value_type == CacheValueTypeEnum.FLOAT:
            str_value = str(float(value))
        elif value_type == CacheValueTypeEnum.BOOL:
            str_value = str(bool(value)).lower()
        elif value_type == CacheValueTypeEnum.NONE:
            str_value = 'null'
        elif value_type in (CacheValueTypeEnum.LIST, CacheValueTypeEnum.DICT,
                            CacheValueTypeEnum.TUPLE, CacheValueTypeEnum.JSON):
            str_value = json.dumps(value)
        else:
            str_value = str(value)
            value_type = CacheValueTypeEnum.STR

        res = self.conn.execute(self.sql_statement_5, (key,))
        if res:
            self.conn.execute(self.sql_statement_6, (key,))

        self.conn.execute(self.sql_statement_4, (key, str_value, value_type.value))

    def delete_sql_cache(self, key: str) -> None:
        """
        删除缓存中指定键的值
        :param key: 缓存键
        :return: None
        """
        self.conn.execute(self.sql_statement_6, (key,))

    def contains_sql_cache(self, key: str) -> bool:
        """
        检查缓存中是否包含指定键
        :param key: 缓存键
        :return: 如果缓存中包含指定键，返回True；否则返回False
        """
        res = self.conn.execute(self.sql_statement_7, (key,))
        return res[0]['COUNT(*)'] > 0 if res else False

    def clear_sql_cache(self) -> None:
        """
        清空缓存中的所有键值对
        :return: None
        """
        self.conn.execute(self.sql_statement_8)

    def get_sql_all(self):
        return {i.get('key'): self.get_sql_cache(i.get('key')) for i in self.conn.execute(self.sql_statement_2)}



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2025-07-04 14:10
# @Author : 毛鹏
from assertpy import assert_that

from ...decorator import sync_method_callback
from ...models import MethodModel


def _assert_that(actual):
    if actual is None:
        raise AssertionError(f"实际值不能为 None ，可能是在获取实际值的时候就失败了！")
    return assert_that(actual)


class ContainAssertion:
    """包含什么"""

    @staticmethod
    @sync_method_callback('文本断言', '包含什么', 0, [
        MethodModel(f='actual', d=True), MethodModel(f='expect', p='请输入断言值', d=True)])
    def p_contains(actual: str, expect: str):
        """包含expect"""
        try:
            _assert_that(actual).contains(expect)
        except AssertionError as e:
            raise AssertionError(f'实际={actual}, 预期={expect}') from e

    @staticmethod
    @sync_method_callback('文本断言', '包含什么', 1, [
        MethodModel(f='actual', d=True), MethodModel(f='expect', p='请输入断言值', d=True)])
    def p_is_equal_to_ignoring_case(actual: str, expect: str):
        """忽略大小写等于expect"""
        try:
            _assert_that(actual).is_equal_to_ignoring_case(expect)
        except AssertionError as e:
            raise AssertionError(f'实际={actual}, 预期={expect}') from e

    @staticmethod
    @sync_method_callback('文本断言', '包含什么', 2, [
        MethodModel(f='actual', d=True), MethodModel(f='expect', p='请输入断言值', d=True)])
    def p_contains_ignoring_case(actual: str, expect: str):
        """包含忽略大小写expect"""
        try:
            _assert_that(actual).contains_ignoring_case(expect)
        except AssertionError as e:
            raise AssertionError(f'实际={actual}, 预期={expect}') from e

    @staticmethod
    @sync_method_callback('文本断言', '包含什么', 3, [
        MethodModel(f='actual', d=True), MethodModel(f='expect', p='请输入断言值', d=True)])
    def p_contains_only(actual: str, expect: str):
        """仅包含expect"""
        try:
            _assert_that(actual).contains_only(expect)
        except AssertionError as e:
            raise AssertionError(f'实际={actual}, 预期={expect}') from e

    @staticmethod
    @sync_method_callback('文本断言', '包含什么', 4, [
        MethodModel(f='actual', d=True), MethodModel(f='expect', p='请输入断言值', d=True)])
    def p_does_not_contain(actual: str, expect: str):
        """不包含expect"""
        try:
            _assert_that(actual).does_not_contain(expect)
        except AssertionError as e:
            raise AssertionError(f'实际={actual}, 预期={expect}') from e



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2025-07-04 14:10
# @Author : 毛鹏
from assertpy import assert_that

from ...decorator import sync_method_callback
from ...models import MethodModel


def _assert_that(actual):
    if actual is None:
        raise AssertionError(f"实际值不能为 None ，可能是在获取实际值的时候就失败了！")
    return assert_that(actual)

class WhatIsItAssertion:
    """是什么"""

    @staticmethod
    @sync_method_callback('文本断言', '是什么', 0, [
        MethodModel(f='actual', d=True)])
    def p_is_not_none(actual):
        """不是null"""
        try:
            assert_that(actual).is_not_none()
        except AssertionError as e:
            raise AssertionError(f'实际={actual}, 预期=不是null') from e

    @staticmethod
    @sync_method_callback('文本断言', '是什么', 1, [
        MethodModel(f='actual', d=True)])
    def p_is_none(actual):
        """是null"""
        try:
            assert_that(actual).is_none()
        except AssertionError as e:
            raise AssertionError(f'实际={actual}, 预期=是null') from e

    @staticmethod
    @sync_method_callback('文本断言', '是什么', 2, [
        MethodModel(f='actual', d=True)])
    def p_is_empty(actual):
        """是空字符串"""
        try:
            _assert_that(actual).is_empty()
        except AssertionError as e:
            raise AssertionError(f'实际={actual}, 预期=是空字符串') from e

    @staticmethod
    @sync_method_callback('文本断言', '是什么', 3, [
        MethodModel(f='actual', d=True)])
    def p_is_not_empty(actual):
        """不是空符串"""
        try:
            _assert_that(actual).is_not_empty()
        except AssertionError as e:
            raise AssertionError(f'实际={actual}, 预期=不是空符串') from e

    @staticmethod
    @sync_method_callback('文本断言', '是什么', 4, [
        MethodModel(f='actual', d=True)])
    def p_is_false(actual):
        """是false"""
        try:
            assert_that(actual).is_false()
        except AssertionError as e:
            raise AssertionError(f'实际={actual}, 预期=是false') from e

    @staticmethod
    @sync_method_callback('文本断言', '是什么', 5, [
        MethodModel(f='actual', d=True)])
    def p_is_true(actual):
        """是true"""
        try:
            assert_that(actual).is_true()
        except AssertionError as e:
            raise AssertionError(f'实际={actual}, 预期=是true') from e

    @staticmethod
    @sync_method_callback('文本断言', '是什么', 6, [
        MethodModel(f='actual', d=True)])
    def p_is_alpha(actual):
        """是字母"""
        try:
            _assert_that(actual).is_alpha()
        except AssertionError as e:
            raise AssertionError(f'实际={actual}, 预期=是字母') from e

    @staticmethod
    @sync_method_callback('文本断言', '是什么', 7, [
        MethodModel(f='actual', d=True)])
    def p_is_digit(actual):
        """是数字"""
        try:
            _assert_that(actual).is_digit()
        except AssertionError as e:
            raise AssertionError(f'实际={actual}, 预期=是数字') from e





# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description:
# @Time   : 2023-09-09 23:17
# @Author : 毛鹏
import aiomysql
from aiomysql import OperationalError, InternalError, ProgrammingError

from ..exceptions import MangoToolsError
from ..exceptions.error_msg import ERROR_MSG_0001, ERROR_MSG_0033, ERROR_MSG_0035, ERROR_MSG_0034
from ..models import MysqlConingModel


class AsyncMysqlConnect:
    """异步MySQL连接池工具类"""

    def __init__(self, mysql_config: MysqlConingModel, is_c: bool = True, is_rud: bool = False):
        self.is_c = is_c
        self.is_rud = is_rud
        self.mysql_config = mysql_config
        self.pool = None

    async def initialize(self):
        """初始化连接池（需显式调用）"""
        try:
            self.pool = await aiomysql.create_pool(
                host=self.mysql_config.host,
                port=self.mysql_config.port,
                user=self.mysql_config.user,
                password=self.mysql_config.password,
                db=self.mysql_config.database,
                autocommit=True,
                minsize=1,
                maxsize=50  # 可根据并发需求调整
            )
        except OperationalError:
            raise MangoToolsError(*ERROR_MSG_0001)
        except InternalError:
            raise MangoToolsError(*ERROR_MSG_0033, value=(self.mysql_config.database,))

    async def close(self):
        """关闭连接池"""
        if self.pool:
            self.pool.close()
            await self.pool.wait_closed()
            self.pool = None

    async def __aenter__(self):
        await self.initialize()
        return self

    async def __aexit__(self, exc_type, exc_val, exc_tb):
        await self.close()

    async def condition_execute(self, sql: str) -> list[dict] | list | int | None:
        """条件执行SQL（根据is_c/is_rud判断是否执行）"""
        if sql is None or sql == '':
            return None
        if sql.strip().upper().startswith('SELECT'):
            if self.is_c:
                return await self.execute(sql)
        else:
            if self.is_rud:
                return await self.execute(sql)

    async def execute(self, sql: str) -> list[dict] | int:
        """执行SQL并返回结果"""
        async with self.pool.acquire() as conn:
            async with conn.cursor(aiomysql.DictCursor) as cursor:
                try:
                    await cursor.execute(sql)
                except ProgrammingError:
                    raise MangoToolsError(*ERROR_MSG_0034, value=(sql,))
                except InternalError:
                    raise MangoToolsError(*ERROR_MSG_0035)
                except OperationalError:
                    raise MangoToolsError(*ERROR_MSG_0034, value=(sql,))

                if sql.strip().upper().startswith('SELECT'):
                    return await cursor.fetchall()
                else:
                    await conn.commit()
                    return cursor.rowcount


# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description:
# @Time   : 2022-11-04 22:05
# @Author : 毛鹏
import logging
import os
from logging import handlers

import colorlog


class LogHandler:
    """ 日志打印封装"""
    level_relations = {
        'debug': logging.DEBUG,
        'info': logging.INFO,
        'warning': logging.WARNING,
        'error': logging.ERROR,
        'critical': logging.CRITICAL
    }

    def __init__(self, file_name: str, level: str):
        log_dir = os.path.dirname(file_name)
        if log_dir and not os.path.exists(log_dir):
            os.makedirs(log_dir, exist_ok=True)
        self.logger = logging.getLogger(file_name)
        fmt = "%(levelname)-8s[%(asctime)s][%(filename)s:%(lineno)d] %(message)s"
        format_str = logging.Formatter(fmt)
        self.logger.setLevel(self.level_relations.get(level, logging.DEBUG))

        screen_output = logging.StreamHandler()
        screen_output.setFormatter(self.log_format(level))

        time_rotating = handlers.TimedRotatingFileHandler(
            filename=file_name,
            when="D",
            backupCount=3,
            encoding='utf-8'
        )
        time_rotating.setFormatter(format_str)

        self.logger.addHandler(screen_output)
        self.logger.addHandler(time_rotating)

    @classmethod
    def log_format(cls, level):
        if level in ["debug", "info"]:
            fmt = "%(log_color)s[%(asctime)s] [%(levelname)s]: %(message)s"
        else:
            fmt = "%(log_color)s[%(asctime)s] [%(filename)s-->行:%(lineno)d] [%(levelname)s]: %(message)s"
        format_str = colorlog.ColoredFormatter(
            fmt,
            log_colors={
                'DEBUG': 'cyan',
                'INFO': 'green',
                'WARNING': 'yellow',
                'ERROR': 'red',
                'CRITICAL': 'purple',
            }
        )
        return format_str
